'use client';

import {
  Box,
  Button,
  Container,
  Flex,
  FormControl,
  FormLabel,
  Heading,
  Input,
  Text,
  Textarea,
  useColorModeValue,
  VStack,
  FormErrorMessage,
  Link,
  Icon,
  Stack,
} from '@chakra-ui/react';
import { FaTwitter, FaLinkedin, FaGithub, FaEnvelope } from 'react-icons/fa';
import { useState } from 'react';

export default function ContactPage() {
  const [form, setForm] = useState({ name: '', email: '', message: '' });
  const [errors, setErrors] = useState({ name: '', email: '', message: '' });

  const validate = () => {
    let valid = true;
    let errs = { name: '', email: '', message: '' };

    if (!form.name.trim()) {
      errs.name = 'Name is required';
      valid = false;
    }
    if (!form.email.trim()) {
      errs.email = 'Email is required';
      valid = false;
    } else if (!/\S+@\S+\.\S+/.test(form.email)) {
      errs.email = 'Email is invalid';
      valid = false;
    }
    if (!form.message.trim()) {
      errs.message = 'Message is required';
      valid = false;
    }
    setErrors(errs);
    return valid;
  };

  const handleChange = (e: React.ChangeEvent<HTMLInputElement | HTMLTextAreaElement>) => {
    setForm({ ...form, [e.target.name]: e.target.value });
  };

  const handleSubmit = (e: React.FormEvent) => {
    e.preventDefault();
    if (!validate()) return;

 
  };

  const bg = useColorModeValue('white', 'gray.800');
  const borderColor = useColorModeValue('gray.200', 'gray.700');
  const accentColor = useColorModeValue('teal.500', 'teal.300');
  const textColor = useColorModeValue('gray.700', 'gray.300');

  return (
    <Box
      minH="100vh"
      bgGradient="linear(to-br, teal.50, white)"
      py={{ base: 10, md: 20 }}
      px={{ base: 4, md: 0 }}
      display="flex"
      alignItems="center"
      justifyContent="center"
    >
      <Container maxW="7xl" bg={bg} boxShadow="2xl" borderRadius="xl" p={{ base: 8, md: 16 }}>
        <Flex
          direction={{ base: 'column', md: 'row' }}
          gap={{ base: 12, md: 24 }}
          align="center"
          justify="space-between"
        >
          {/* Left side: Welcome & Info */}
          <Box flex="1" maxW={{ md: '450px' }}>
            <Heading
              as="h1"
              size="2xl"
              mb={6}
              fontWeight="extrabold"
              letterSpacing="tight"
              color={accentColor}
            >
              Let's Connect
            </Heading>
            <Text fontSize="lg" mb={6} color={textColor} lineHeight="tall">
              Got a question, feedback, or story to share? Fill out the form and I'll get back to
              you shortly.
            </Text>

            <Stack direction="row" spacing={6} mt={4}>
              <Link href="mailto:hello@yourblog.com" aria-label="Email" color={accentColor} _hover={{ color: 'teal.700' }}>
                <Icon as={FaEnvelope} boxSize={6} />
              </Link>
              <Link href="https://twitter.com/yourhandle" isExternal aria-label="Twitter" color={accentColor} _hover={{ color: 'teal.700' }}>
                <Icon as={FaTwitter} boxSize={6} />
              </Link>
              <Link href="https://linkedin.com/in/yourprofile" isExternal aria-label="LinkedIn" color={accentColor} _hover={{ color: 'teal.700' }}>
                <Icon as={FaLinkedin} boxSize={6} />
              </Link>
              <Link href="https://github.com/yourusername" isExternal aria-label="GitHub" color={accentColor} _hover={{ color: 'teal.700' }}>
                <Icon as={FaGithub} boxSize={6} />
              </Link>
            </Stack>
          </Box>

          {/* Right side: Form */}
          <Box
            flex="1"
            bg={useColorModeValue('gray.50', 'gray.900')}
            borderRadius="xl"
            p={8}
            boxShadow="lg"
          >
            <form onSubmit={handleSubmit} noValidate>
              <VStack spacing={5} align="stretch">
                <FormControl isInvalid={!!errors.name} isRequired>
                  <FormLabel htmlFor="name" fontWeight="semibold">
                    Name
                  </FormLabel>
                  <Input
                    id="name"
                    name="name"
                    value={form.name}
                    onChange={handleChange}
                    placeholder="Your full name"
                    size="lg"
                    bg={useColorModeValue('white', 'gray.800')}
                    _focus={{ borderColor: accentColor, boxShadow: `0 0 0 1px ${accentColor}` }}
                    borderRadius="md"
                  />
                  <FormErrorMessage>{errors.name}</FormErrorMessage>
                </FormControl>

                <FormControl isInvalid={!!errors.email} isRequired>
                  <FormLabel htmlFor="email" fontWeight="semibold">
                    Email
                  </FormLabel>
                  <Input
                    id="email"
                    name="email"
                    type="email"
                    value={form.email}
                    onChange={handleChange}
                    placeholder="you@example.com"
                    size="lg"
                    bg={useColorModeValue('white', 'gray.800')}
                    _focus={{ borderColor: accentColor, boxShadow: `0 0 0 1px ${accentColor}` }}
                    borderRadius="md"
                  />
                  <FormErrorMessage>{errors.email}</FormErrorMessage>
                </FormControl>

                <FormControl isInvalid={!!errors.message} isRequired>
                  <FormLabel htmlFor="message" fontWeight="semibold">
                    Message
                  </FormLabel>
                  <Textarea
                    id="message"
                    name="message"
                    rows={6}
                    value={form.message}
                    onChange={handleChange}
                    placeholder="Write your message here..."
                    size="lg"
                    bg={useColorModeValue('white', 'gray.800')}
                    _focus={{ borderColor: accentColor, boxShadow: `0 0 0 1px ${accentColor}` }}
                    borderRadius="md"
                    resize="vertical"
                  />
                  <FormErrorMessage>{errors.message}</FormErrorMessage>
                </FormControl>

                <Button
                  type="submit"
                  colorScheme="teal"
                  size="lg"
                  fontWeight="bold"
                  boxShadow="md"
                  _hover={{ boxShadow: 'lg' }}
                  _active={{ boxShadow: 'inner' }}
                  alignSelf="start"
                >
                  Send Message
                </Button>
              </VStack>
            </form>
          </Box>
        </Flex>
      </Container>
    </Box>
  );
}
